@@ -56,8 +56,9 @@
 #define UNICODE_ZERO_WIDTH_SPACE "\xe2\x80\x8b"
 #define UNICODE_NBSP "\xc2\xa0"
 
-#define SPACES_PER_INDENTATION 4
-#define SPACES_PER_LIST_LEVEL 8
+#define SPACES_PER_INDENTATION 3
+#define SPACES_PER_LIST_LEVEL 3
+#define SPACES_ORDERED_LIST_FIRST_LEVEL 6
 #define MINIMAL_PARAGRAPH_WIDTH 5
 #define TAB_LENGTH 8
 
@@ -276,8 +277,6 @@ void		e_html_editor_view_set_is_message_from_edit_as_new
 void		e_html_editor_view_insert_quoted_text
 						(EHTMLEditorView *view,
 						 const gchar *text);
-WebKitDOMElement *
-		get_parent_block_element	(WebKitDOMNode *node);
 void		e_html_editor_view_set_link_color
 						(EHTMLEditorView *view,
 						 GdkRGBA *color);
@@ -293,6 +292,8 @@ void		e_html_editor_view_redo 	(EHTMLEditorView *view);
 void		e_html_editor_view_insert_new_history_event
 						(EHTMLEditorView *view,
 						 EHTMLEditorViewHistoryEvent *event);
+void		e_html_editor_view_clear_history
+						(EHTMLEditorView *view);
 gboolean	e_html_editor_view_is_undo_redo_in_progress
 						(EHTMLEditorView *view);
 void		e_html_editor_view_set_undo_redo_in_progress
@@ -302,6 +303,8 @@ void		e_html_editor_view_block_style_updated_callbacks
 						(EHTMLEditorView *view);
 void		e_html_editor_view_unblock_style_updated_callbacks
 						(EHTMLEditorView *view);
+gboolean	e_html_editor_view_is_pasting_content_from_itself
+						(EHTMLEditorView *view);
 G_END_DECLS
 
 #endif /* E_HTML_EDITOR_VIEW_H */
